@@ -6,7 +6,7 @@ package fa_code;
 #
 #   Net::FullAuto is powerful network process automation
 #   software that has been in un-released development for
-#   more than seven years. For this reason, you may find
+#   more than eleven years. For this reason, you may find
 #   it to be useful for many process automation projects.
 #   Because it has been worked on for so long, it may appear
 #   to work well, and pass a number of non-intensive tests.
@@ -26,9 +26,10 @@ package fa_code;
 #
 ################################################################
 
+use strict;
+use warnings;
 our $test=0;our $timeout=0;
 require Exporter;
-use warnings;
 #use threads ();
 #use Thread::Queue;
 our @ISA = qw(Exporter Net::FullAuto::FA_Core);
@@ -65,7 +66,7 @@ $timeout=90;
 ##############################################
 
 ######## SET PASSWORD FILE LOCATION  #########
-if ($OS eq 'cygwin') {
+if ($^O eq 'cygwin') {
    $passwd_file_loc="/passwds_ms";
 } else {
    $passwd_file_loc="/passwds_ux"
